#
# spec file for package perl-Pod-Usage
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Pod-Usage
Name:           perl-Pod-Usage
Version:        2.05
Release:        1.1
#Upstream: Artistic-1.0 or GPL-1.0-or-later
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Extracts POD documentation and shows usage information
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MAREKR/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Pod::Perldoc) >= 3.28
BuildRequires:  perl(Pod::Simple) >= 3.40
BuildRequires:  perl(Pod::Text) >= 4.00
Requires:       perl(Pod::Perldoc) >= 3.28
Requires:       perl(Pod::Simple) >= 3.40
Requires:       perl(Pod::Text) >= 4.00
%{perl_requires}

%description
*pod2usage* will print a usage message for the invoking script (using its
embedded pod documentation) and then exit the script with the desired exit
status. The usage message printed may have any one of three levels of
"verboseness": If the verbose level is 0, then only a synopsis is printed.
If the verbose level is 1, then the synopsis is printed along with a
description (if present) of the command line options and arguments. If the
verbose level is 2, then the entire manual page is printed.

%prep
%autosetup  -n %{cpan_name}-%{version} -p1

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
# MANUAL BEGIN
VERSION=$(echo %{version} | sed -e "s|\.|_|g")
pushd %buildroot%_bindir >/dev/null
for file in *; do
    mv -v $file $file-${VERSION}
done
popd >/dev/null
pushd %buildroot%_mandir/man1
for file in *.1; do
    mv -v $file ${file/.1/}-${VERSION}.1
done
popd >/dev/null
pushd %buildroot%_mandir/man3
for file in *.3pm; do
    mv -v $file ${file/.3pm/}-${VERSION}.3pm
done
popd >/dev/null
# MANUAL END
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Mar 30 2025 Tina Müller <timueller+perl@suse.de>
- updated to 2.05
  see /usr/share/doc/packages/perl-Pod-Usage/Changes
  2.05      2025-03-29
  - merged PR #27, fixing spurious Exporter inheritance
  2.04      2025-03-25
  - merged three pull requests, removing the internal Pod::PlainText
  - fixed Github: Relies on formatter to inherit from Exporter #17
* Sun May 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.03
  see /usr/share/doc/packages/perl-Pod-Usage/Changes
  2.03      2022-05-21
  2.02      2022-05-21
  - merged two pull requests (https://github.com/Dual-Life/Pod-Usage),
    thanks Nicolas and Karl
* Wed Oct 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.01
  see /usr/share/doc/packages/perl-Pod-Usage/Changes
* Mon Mar 16 2020 <timueller+perl@suse.de>
- updated to 1.70
  see /usr/share/doc/packages/perl-Pod-Usage/CHANGES
  1.70 (marekr)
  - CPAN#115847: pod2usage exits with error when using "-verbose 3" with STDIN
    Addressed in pod2usage script, and updated POD
  - CPAN#122941: Pod::Usage::pod2usage() problem with $Config{scriptdir}
    Should be fixed by 1.69 already; reviewed code
  - CPAN#121489: I<> not emphasized when used with Pod::Text::Termcap
    Added specific support of ::Termcap
  - CPAN#114697: Sample code syntax error in documentation for Pod-Usage
    Fixed. Well spotted!
  - CPAN#125337: Typo in pod
    Fixed. Well spotted, too!
  - CPAN#130418: Fix parent directory in pod2usage auxiliary script
    Patch accepted, thanks!
  - CPAN#131845: $Config{pager} string can have arguments
    fixed by changing the system() command from using the array form to
    string form, and escape/quote the file path to protect any metacharacters
    in the file path
  - CPAN#131844: preferring PAGER to $Config{pager}
    Fixed with the above CPAN#131845
* Tue May 31 2016 coolo@suse.com
- updated to 1.69
  see /usr/share/doc/packages/perl-Pod-Usage/CHANGES
  1.69 (marekr)
  - CPAN#111313: Makefile creation issue with Pod-Usage-1.68
    thanks to H M Brand for the suggestion on how to create a more portable
    tar.gz distribution file
  - CPAN#109830: Tests fail
    bundle some old Pod::Parser modules in the test so that there is no more
    dependency. This has to refactored one day to entirely get rid of that
* Mon May 23 2016 coolo@suse.com
- updated to 1.68
  see /usr/share/doc/packages/perl-Pod-Usage/CHANGES
  1.68 (marekr)
  - CPAN#102529: License declaration mismatch
    unified the license for Pod-Usage to "as Perl itself", and corrected authors
  - CPAN#109830: Tests fail
    added prerequisite for Pod::Text 4.00 to avoid running tests with outdated
    Pod::Text
  - CPAN#110443: [PATCH] fix -perldoc option in pod2usage() method
    added missing '-'
  - CPAN#110446: [feature request] -perldocopt for supplying perldoc options
    added this option; split of string on whitespace is not optimal, but
    should do the job
* Wed Apr 15 2015 coolo@suse.com
- updated to 1.67
  see /usr/share/doc/packages/perl-Pod-Usage/CHANGES
  1.67 (marekr)
  - added options -perlcmd and -perldoc to allow for non-standard installations
    of perl and the perldoc script. Thanks to Markus Jansen for the patch
  1.66 (marekr)
  - CPAN#102116: pod2usage() -sections omits section with subsection specified
    added more precise documentation about the -section syntax and semantics
  - CPAN#102117: pod2usage() changes formatting
    added documentation to describe what formatting changes pod2usage applies
  - CPAN#102101: New tests fail when in core
    changed the way the tests find their dependencies. Thanks to BINGOS for
    the patch, applied in slightly modified way
  1.65 (marekr)
  - CPAN#81059: [RT #115534]: Pod::Usage Failes to Select -sections with Negation
    fixed a specific corner case for section selection
  - CPAN#101538: Pod::Usage doesn't handle E<copy> correctly
    introduced a utf8 option; this may actually not solve the problem, but
    it is the best we can do for the moment
  - CPAN#101581: pod2usage() -sections omits marked-up text from =head lines
    make sure that marked-up text is not skipped
* Wed Sep 17 2014 coolo@suse.com
- updated to 1.64
  - CPAN#93170: Abstract in pod doesn't follow convention
    fixed the NAME section
  - CPAN#86932: documentation does not work with use strict
    rewritten parts of the DESCRIPTION section
  - CPAN#86776: "pod2usage -verbose 2 FILE" is broken when perldoc is missing
    verified that pod2usage acts decently if perldoc is missing
    note: a Perl installation without perldoc is like a haunted house
    without ghosts
  1.63 (marekr)
  - CPAN#85477: Module version not updated in last release
  ...fixed
  - CPAN#85478: typo fixes
  ...corrected
  1.62 (marekr)
  Patches provided by rjbs - many thanks!
  - These commits update Pod::Usage to only use Pod::Simple, so that any
  reliance on Pod::Parser is removed, making it easier to remove Pod::Parser
  from core.
  - [PATCH 1/4] update Makefile: strict, INSTALLDIR, 5.6
  - [PATCH 2/4] we will start to require perl 5.6 from here on out
  - [PATCH 3/4] always use Pod::Text as default base class
  - [PATCH 4/4] eliminate the branch in which Pod::Parser would be used
  This commit is intended entirely to free Pod::Usage from any reliance on
  Pod::Parser.
  * Usage.pm now defaults to using Pod::Text, rather than checking $] to pick.
  * $Pod::Select::MAX_HEADING_LEVEL is replaced with a local var
  * &Pod::Select::_compile_section_spec is copied into this module
    This isn't the most elegant fix, but it's a bit of a ball of mud. The code
    is written to let you alter @ISA at runtime to something that is derived
    either from Pod::Parser or Pod::Simple. This should probably be more
    explicitly limited to Pod::Simple in future releases.
* Sat May 11 2013 lars@linux-schulserver.de
- fix build on old distributions by renaming the binaries for now
* Wed May  8 2013 lars@linux-schulserver.de
- initial package 1.61
